ContractDeclarationError class

An error thrown when a contract declaration is invalid. This may be due to:

  1. The contract not being defined in the script.
  2. The contract missing definitions for implementations.
Inheritance

Constructors

ContractDeclarationError(String contractName, {List<String>? implementations, List<String>? foundImplementations, required ParserRuleContext? ctx})
An error thrown when a contract declaration is invalid. This may be due to:

Properties

contractName String
The name of the contract that caused the error.
final
ctx → ParserRuleContext?
The statement that caused the error.
finalinherited
foundImplementations List<String>?
The number of implementations found in the contract declaration.
final
hashCode int
The hash code for this object.
no setterinherited
implementations List<String>?
The number of implementations expected by the contract.
final
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity int
The severity of the error according to LSP specification.
finalinherited
span Span?
The context in which the error occurred, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited