ContractDeclarationError class
An error thrown when a contract declaration is invalid. This may be due to:
- The contract not being defined in the script.
- In this case, implementations and foundImplementations are expected to be null.
- The contract missing definitions for implementations.
- In this case, implementations and foundImplementations are expected to be non-null.
- Inheritance
-
- Object
- AnalyzerMessage
- SemanticError
- ContractDeclarationError
Constructors
Properties
- contractName → String
-
The name of the contract that caused the error.
final
- ctx → ParserRuleContext?
-
The statement that caused the error.
finalinherited
-
foundImplementations
→ List<
String> ? -
The number of implementations found in the contract declaration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
implementations
→ List<
String> ? -
The number of implementations expected by the contract.
final
- message → String
-
The error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → int
-
The severity of the error according to LSP specification.
finalinherited
- span → Span?
-
The context in which the error occurred, if available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited