RequiredMetadataError class
An error thrown when required metadata is not defined in the script.
- Inheritance
-
- Object
- AnalyzerMessage
- SemanticError
- RequiredMetadataError
Constructors
- RequiredMetadataError(String metadataName, {required ParserRuleContext? ctx})
- An error thrown when required metadata is not defined in the script.
Properties
- ctx → ParserRuleContext?
-
The statement that caused the error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message.
finalinherited
- metadataName → String
-
The name of the required metadata that is missing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → int
-
The severity of the error according to LSP specification.
finalinherited
- span → Span?
-
The context in which the error occurred, if available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited