ScriptPermission class
Represents a permission required or granted to execute script operations.
Permissions are identified by a namespace and a name, matching the DSL's
declared permissions statements. Custom host permissions use the external namespace.
Constructors
- ScriptPermission.custom(String name)
-
Creates a custom host-defined permission with the
externalnamespace.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
The method or action within the namespace (e.g., 'read', 'write', 'client').
final
- namespace → String
-
The namespace associated with this permission (e.g., 'fs', 'ntwk', or 'external').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the DSL-style string representation
namespace::method.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- networkClient → const ScriptPermission
-
Permission to perform network client requests (
ntwk::client). - networkServer → const ScriptPermission
-
Permission to start a network server (
ntwk::server). - readFiles → const ScriptPermission
-
Permission to read from the filesystem (
fs::read). - writeFiles → const ScriptPermission
-
Permission to write to the filesystem (
fs::write).